	DIMENSION x(100),y(100)
	REAL	radius,theta,thinc,x,y
	INTEGER	i,idev,nm1,n,ip1,j

	CALL	export(5,6)
	CALL	askdev(idev)
	write(6,1)
1	FORMAT('How many points and what radius? ',$)
	read(5,2)N,radius
2	FORMAT(i8,f8.4)
	CALL	start(2)
	CALL	plot(9.5,7.375,-3)
	thinc=6.283185307/float(n)
	theta=0.0
	DO 5 i=1,n
		theta=theta+thinc
		x(i)=radius*cos(theta)
		y(i)=radius*sin(theta)
5	CONTINUE
C	join point to point.
	nm1=n-1
	DO 15 i=1,nm1
		ip1=i+1
		DO 10 j=ip1,n
			CALL	plot(x(i),y(i),3)
			CALL	plot(x(j),y(j),2)
10		CONTINUE
15	CONTINUE
	CALL	enplot
	END
